@@ -1,5 +1,4 @@
 #include "syntaxcheck.h"
-#include "latexdocument.h"
 #include "latexeditorview_config.h"
 #include "spellerutility.h"
 #include "tablemanipulation.h"
@@ -578,6 +577,68 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
         // used for formula -> brace -> {....}
         if(!activeEnv.isEmpty() && activeEnv.top().endingColumn>=0 && tk.start>activeEnv.top().endingColumn){
             Environment env=activeEnv.pop();
+        }
+        // special treatment for ExplSyntaxOff
+        // it is used to toggle expl3 mode off
+        if(!activeEnv.isEmpty() && activeEnv.top().name == "expl3"){
+            const QString word=tk.getText();
+            if( word == "\\ExplSyntaxOff"){
+                activeEnv.pop();
+                continue;
+            }
+            if(tk.type==Token::commandUnknown || tk.type==Token::command){
+                // collect next parts
+                // e.g. \cs_new:Npn is split into \cs _ new : Npn
+                const int start = tk.start;
+                int end=tk.start+tk.length;
+                int colonPosition=-1;
+                for(++i;i<tl.length();++i){
+                    Token tk2= tl[i];
+                    if(end != tk2.start){
+                        // token does not adjoin previous one
+                        --i;
+                        break;
+                    }
+                    end+=tk2.length;
+                    if(tk2.type==Token::word){
+                        continue;
+                    }
+                    if(tk2.type==Token::punctuation){
+                        if(tk2.getText()=="_"){
+                            continue;
+                        }
+                        if(tk2.getText()==":"){
+                            colonPosition=end;
+                            continue;
+                        }
+                    }
+                    end-=tk2.length;
+                    --i;
+                    break; // unwanted element, stop joing for latex3 command
+                }
+                if(colonPosition>=0) {
+                    // highlight part after colon as math/number
+                    // highlight command part
+                    Error elem;
+                    elem.range = QPair<int, int>(start, colonPosition-start);
+                    elem.format=mFormatList["#pictureHighlight"];
+                    elem.type = ERR_highlight;
+                    newRanges.append(elem); // highlight
+                    // highlight after column
+                    elem.range = QPair<int, int>(colonPosition, end-colonPosition);
+                    elem.format=mFormatList["math"];
+                    elem.type = ERR_highlight;
+                    newRanges.append(elem); // highlight
+                }else{
+                    // ltx3 command w/o colon inside
+                    Error elem;
+                    elem.range = QPair<int, int>(start, end-start);
+                    elem.format=mFormatList["#pictureHighlight"];
+                    elem.type = ERR_highlight;
+                    newRanges.append(elem); // highlight
+                }
+            }
+            continue;
         }
 		// ignore commands in definition arguments e.g. \newcommand{cmd}{definition}
 		if (stackContainsDefinition(stack)) {
@@ -980,9 +1041,9 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
             if (word.contains('@')) {
                 continue; //ignore commands containg @
             }
-			if(!tk.optionalCommandName.isEmpty()){
+            if(!tk.optionalCommandName.isEmpty() && !tk.optionalCommandName.contains("/")){
 				word=tk.optionalCommandName;
-			}
+            }
 			Token tkEnvName;
 
 			if (word == "\\begin" || word == "\\end") {
@@ -992,6 +1053,21 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					word = word + line.mid(tkEnvName.start, tkEnvName.length);
 				}
 			}
+            // special treatment for \ExplSyntaxOn, \ExplSyntaxOff
+            // \ProvidesExplPackage, \ProvidesExplClass and \ProvidesExplFile
+            // activate latex3 mode which ignores _ in commandnames
+            if(word=="\\ExplSyntaxOn" || word=="\\ProvidesExplPackage" || word=="\\ProvidesExplClass" || word=="\\ProvidesExplFile"){
+                Environment env;
+                env.name = "expl3";
+                env.id = 1; // to be changed
+                env.dlh = dlh;
+                env.ticket = ticket;
+                env.level = tk.level;
+                env.startingColumn=tk.start+tk.length;
+                activeEnv.push(env);
+                continue;
+            }
+
             // special treatment for & in math
             if(word=="&" && containsEnv("math", activeEnv)){
                 Error elem;
@@ -1084,13 +1160,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					continue;
 				}
 				if (word == "\\multicolumn") {
-					QRegExp rxMultiColumn("\\\\multicolumn\\{(\\d+)\\}\\{.+\\}\\{.+\\}");
-					rxMultiColumn.setMinimal(true);
-					int res = rxMultiColumn.indexIn(line, tk.start);
-					if (res > -1) {
+                    static QRegularExpression rxMultiColumn("\\\\multicolumn\\{(\\d+?)\\}\\{.+?\\}\\{.+?\\}");
+                    QRegularExpressionMatch rxMultiColumnMatch = rxMultiColumn.match(line, tk.start);
+                    if (rxMultiColumnMatch.hasMatch()) {
 						// multicoulmn before &
 						bool ok;
-						int c = rxMultiColumn.cap(1).toInt(&ok);
+                        int c = rxMultiColumnMatch.captured(1).toInt(&ok);
 						if (ok) {
 							activeEnv.top().excessCol += c - 1;
 						}
